import java.io.*; 

/* Copyright K. Lano 2014-2018 
   Package: Class diagram  */ 
 
public class Generalisation extends ModelElement
{ private Entity ancestor;
  private Entity descendent;
  private boolean realization = false; // true if ancestor.isInterface()

  public Generalisation(String nme) 
  { super(nme); } 

  public Generalisation(Entity ans, Entity dec)
  { super(dec.getName() + "_" + ans.getName());
    ancestor = ans;
    descendent = dec;
  }

  public void setAncestor(Entity e)
  { ancestor = e; } 

  public void setDescendent(Entity e)
  { descendent = e; } 

  public Entity getAncestor() { return ancestor; }

  public Entity getDescendent() { return descendent; }

  public void setRealization(boolean r)
  { realization = r; } 

  public boolean isRealization() 
  { return realization; } 

  public String toString()
  { return descendent.getName() + " ---|> " +
           ancestor.getName();
  }

  public void asTextModel(PrintWriter out) 
  { String nme = getName(); 
    out.println(nme + " : Generalization"); 
    out.println(nme + ".name = \"" + nme + "\"");
    out.println(nme + " : " + ancestor + ".specialization"); 
    out.println(nme + ".general = " + ancestor); 
    out.println(nme + " : " + descendent + ".generalization"); 
    out.println(nme + ".specific = " + descendent);  
  } 

  public void generateJava(java.io.PrintWriter out)
  { if (realization)
    { out.println(descendent.getName() + " implements " + 
                       ancestor.getName()); 
    }
    else 
    { out.println(descendent.getName() + " extends " + 
                  ancestor.getName());
    } 
  } 

  public String saveData()
  { return ""; } 
}

